from .aztec_diamond import AztecDiamond
from .game import Game
from .game_2048 import Game2048
from .graph import AbstractGraph
from .klotski import Klotski
from .sliding_block_puzzle import SlidingBlockPuzzle
from .snake import Snake
from .towers_of_hanoi import TowersOfHanoi

__all__ = [
    "Game2048",
    "TowersOfHanoi",
    "AztecDiamond",
    "AbstractGraph",
    "Klotski",
    "SlidingBlockPuzzle",
    "Snake",
    "Game",
]